@@ -67,6 +67,7 @@ class TestCookies(unittest.TestCase):
             ({'XDG_CURRENT_DESKTOP': 'GNOME'}, _LinuxDesktopEnvironment.GNOME),
             ({'XDG_CURRENT_DESKTOP': 'GNOME:GNOME-Classic'}, _LinuxDesktopEnvironment.GNOME),
             ({'XDG_CURRENT_DESKTOP': 'GNOME : GNOME-Classic'}, _LinuxDesktopEnvironment.GNOME),
+            ({'XDG_CURRENT_DESKTOP': 'ubuntu:GNOME'}, _LinuxDesktopEnvironment.GNOME),
 
             ({'XDG_CURRENT_DESKTOP': 'Unity', 'DESKTOP_SESSION': 'gnome-fallback'}, _LinuxDesktopEnvironment.GNOME),
             ({'XDG_CURRENT_DESKTOP': 'KDE', 'KDE_SESSION_VERSION': '5'}, _LinuxDesktopEnvironment.KDE5),
@@ -104,15 +105,31 @@ class TestCookies(unittest.TestCase):
             decryptor = LinuxChromeCookieDecryptor('Chrome', Logger())
             self.assertEqual(decryptor.decrypt(encrypted_value), value)
 
+    def test_chrome_cookie_decryptor_linux_v10_meta24(self):
+        with MonkeyPatch(cookies, {'_get_linux_keyring_password': lambda *args, **kwargs: b''}):
+            encrypted_value = b'v10\x1f\xe4\x0e[\x83\x0c\xcc*kPi \xce\x8d\x1d\xbb\x80\r\x11\t\xbb\x9e^Hy\x94\xf4\x963\x9f\x82\xba\xfe\xa1\xed\xb9\xf1)\x00710\x92\xc8/<\x96B'
+            value = 'DE'
+            decryptor = LinuxChromeCookieDecryptor('Chrome', Logger(), meta_version=24)
+            self.assertEqual(decryptor.decrypt(encrypted_value), value)
+
     def test_chrome_cookie_decryptor_windows_v10(self):
         with MonkeyPatch(cookies, {
-            '_get_windows_v10_key': lambda *args, **kwargs: b'Y\xef\xad\xad\xeerp\xf0Y\xe6\x9b\x12\xc2<z\x16]\n\xbb\xb8\xcb\xd7\x9bA\xc3\x14e\x99{\xd6\xf4&'
+            '_get_windows_v10_key': lambda *args, **kwargs: b'Y\xef\xad\xad\xeerp\xf0Y\xe6\x9b\x12\xc2<z\x16]\n\xbb\xb8\xcb\xd7\x9bA\xc3\x14e\x99{\xd6\xf4&',
         }):
             encrypted_value = b'v10T\xb8\xf3\xb8\x01\xa7TtcV\xfc\x88\xb8\xb8\xef\x05\xb5\xfd\x18\xc90\x009\xab\xb1\x893\x85)\x87\xe1\xa9-\xa3\xad='
             value = '32101439'
             decryptor = WindowsChromeCookieDecryptor('', Logger())
             self.assertEqual(decryptor.decrypt(encrypted_value), value)
 
+    def test_chrome_cookie_decryptor_windows_v10_meta24(self):
+        with MonkeyPatch(cookies, {
+            '_get_windows_v10_key': lambda *args, **kwargs: b'\xea\x8b\x02\xc3\xc6\xc5\x99\xc3\xa3[ j\xfa\xf6\xfcU\xac\x13u\xdc\x0c\x0e\xf1\x03\x90\xb6\xdf\xbb\x8fL\xb1\xb2',
+        }):
+            encrypted_value = b'v10dN\xe1\xacy\x84^\xe1I\xact\x03r\xfb\xe2\xce{^\x0e<(\xb0y\xeb\x01\xfb@"\x9e\x8c\xa53~\xdb*\x8f\xac\x8b\xe3\xfd3\x06\xe5\x93\x19OyOG\xb2\xfb\x1d$\xc0\xda\x13j\x9e\xfe\xc5\xa3\xa8\xfe\xd9'
+            value = '1234'
+            decryptor = WindowsChromeCookieDecryptor('', Logger(), meta_version=24)
+            self.assertEqual(decryptor.decrypt(encrypted_value), value)
+
     def test_chrome_cookie_decryptor_mac_v10(self):
         with MonkeyPatch(cookies, {'_get_mac_keyring_password': lambda *args, **kwargs: b'6eIDUdtKAacvlHwBVwvg/Q=='}):
             encrypted_value = b'v10\xb3\xbe\xad\xa1[\x9fC\xa1\x98\xe0\x9a\x01\xd9\xcf\xbfc'
@@ -121,17 +138,17 @@ class TestCookies(unittest.TestCase):
             self.assertEqual(decryptor.decrypt(encrypted_value), value)
 
     def test_safari_cookie_parsing(self):
-        cookies = \
-            b'cook\x00\x00\x00\x01\x00\x00\x00i\x00\x00\x01\x00\x01\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00Y' \
-            b'\x00\x00\x00\x00\x00\x00\x00 \x00\x00\x00\x00\x00\x00\x008\x00\x00\x00B\x00\x00\x00F\x00\x00\x00H' \
-            b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x03\xa5>\xc3A\x00\x00\x80\xc3\x07:\xc3A' \
-            b'localhost\x00foo\x00/\x00test%20%3Bcookie\x00\x00\x00\x054\x07\x17 \x05\x00\x00\x00Kbplist00\xd1\x01' \
-            b'\x02_\x10\x18NSHTTPCookieAcceptPolicy\x10\x02\x08\x0b&\x00\x00\x00\x00\x00\x00\x01\x01\x00\x00\x00' \
-            b'\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00('
+        cookies = (
+            b'cook\x00\x00\x00\x01\x00\x00\x00i\x00\x00\x01\x00\x01\x00\x00\x00\x10\x00\x00\x00\x00\x00\x00\x00Y'
+            b'\x00\x00\x00\x00\x00\x00\x00 \x00\x00\x00\x00\x00\x00\x008\x00\x00\x00B\x00\x00\x00F\x00\x00\x00H'
+            b'\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x03\xa5>\xc3A\x00\x00\x80\xc3\x07:\xc3A'
+            b'localhost\x00foo\x00/\x00test%20%3Bcookie\x00\x00\x00\x054\x07\x17 \x05\x00\x00\x00Kbplist00\xd1\x01'
+            b'\x02_\x10\x18NSHTTPCookieAcceptPolicy\x10\x02\x08\x0b&\x00\x00\x00\x00\x00\x00\x01\x01\x00\x00\x00'
+            b'\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00(')
 
         jar = parse_safari_cookies(cookies)
         self.assertEqual(len(jar), 1)
-        cookie = list(jar)[0]
+        cookie = next(iter(jar))
         self.assertEqual(cookie.domain, 'localhost')
         self.assertEqual(cookie.port, None)
         self.assertEqual(cookie.path, '/')
@@ -164,7 +181,7 @@ class TestLenientSimpleCookie(unittest.TestCase):
                     attributes = {
                         key: value
                         for key, value in dict(morsel).items()
-                        if value != ""
+                        if value != ''
                     }
                     self.assertEqual(attributes, expected_attributes, message)
 
@@ -174,133 +191,133 @@ class TestLenientSimpleCookie(unittest.TestCase):
         self._run_tests(
             # Copied from https://github.com/python/cpython/blob/v3.10.7/Lib/test/test_http_cookies.py
             (
-                "Test basic cookie",
-                "chips=ahoy; vienna=finger",
-                {"chips": "ahoy", "vienna": "finger"},
+                'Test basic cookie',
+                'chips=ahoy; vienna=finger',
+                {'chips': 'ahoy', 'vienna': 'finger'},
             ),
             (
-                "Test quoted cookie",
+                'Test quoted cookie',
                 'keebler="E=mc2; L=\\"Loves\\"; fudge=\\012;"',
-                {"keebler": 'E=mc2; L="Loves"; fudge=\012;'},
+                {'keebler': 'E=mc2; L="Loves"; fudge=\012;'},
             ),
             (
                 "Allow '=' in an unquoted value",
-                "keebler=E=mc2",
-                {"keebler": "E=mc2"},
+                'keebler=E=mc2',
+                {'keebler': 'E=mc2'},
             ),
             (
                 "Allow cookies with ':' in their name",
-                "key:term=value:term",
-                {"key:term": "value:term"},
+                'key:term=value:term',
+                {'key:term': 'value:term'},
             ),
             (
                 "Allow '[' and ']' in cookie values",
-                "a=b; c=[; d=r; f=h",
-                {"a": "b", "c": "[", "d": "r", "f": "h"},
+                'a=b; c=[; d=r; f=h',
+                {'a': 'b', 'c': '[', 'd': 'r', 'f': 'h'},
             ),
             (
-                "Test basic cookie attributes",
+                'Test basic cookie attributes',
                 'Customer="WILE_E_COYOTE"; Version=1; Path=/acme',
-                {"Customer": ("WILE_E_COYOTE", {"version": "1", "path": "/acme"})},
+                {'Customer': ('WILE_E_COYOTE', {'version': '1', 'path': '/acme'})},
             ),
             (
-                "Test flag only cookie attributes",
+                'Test flag only cookie attributes',
                 'Customer="WILE_E_COYOTE"; HttpOnly; Secure',
-                {"Customer": ("WILE_E_COYOTE", {"httponly": True, "secure": True})},
+                {'Customer': ('WILE_E_COYOTE', {'httponly': True, 'secure': True})},
             ),
             (
-                "Test flag only attribute with values",
-                "eggs=scrambled; httponly=foo; secure=bar; Path=/bacon",
-                {"eggs": ("scrambled", {"httponly": "foo", "secure": "bar", "path": "/bacon"})},
+                'Test flag only attribute with values',
+                'eggs=scrambled; httponly=foo; secure=bar; Path=/bacon',
+                {'eggs': ('scrambled', {'httponly': 'foo', 'secure': 'bar', 'path': '/bacon'})},
             ),
             (
                 "Test special case for 'expires' attribute, 4 digit year",
                 'Customer="W"; expires=Wed, 01 Jan 2010 00:00:00 GMT',
-                {"Customer": ("W", {"expires": "Wed, 01 Jan 2010 00:00:00 GMT"})},
+                {'Customer': ('W', {'expires': 'Wed, 01 Jan 2010 00:00:00 GMT'})},
             ),
             (
                 "Test special case for 'expires' attribute, 2 digit year",
                 'Customer="W"; expires=Wed, 01 Jan 98 00:00:00 GMT',
-                {"Customer": ("W", {"expires": "Wed, 01 Jan 98 00:00:00 GMT"})},
+                {'Customer': ('W', {'expires': 'Wed, 01 Jan 98 00:00:00 GMT'})},
             ),
             (
-                "Test extra spaces in keys and values",
-                "eggs  =  scrambled  ;  secure  ;  path  =  bar   ; foo=foo   ",
-                {"eggs": ("scrambled", {"secure": True, "path": "bar"}), "foo": "foo"},
+                'Test extra spaces in keys and values',
+                'eggs  =  scrambled  ;  secure  ;  path  =  bar   ; foo=foo   ',
+                {'eggs': ('scrambled', {'secure': True, 'path': 'bar'}), 'foo': 'foo'},
             ),
             (
-                "Test quoted attributes",
+                'Test quoted attributes',
                 'Customer="WILE_E_COYOTE"; Version="1"; Path="/acme"',
-                {"Customer": ("WILE_E_COYOTE", {"version": "1", "path": "/acme"})}
+                {'Customer': ('WILE_E_COYOTE', {'version': '1', 'path': '/acme'})},
             ),
             # Our own tests that CPython passes
             (
                 "Allow ';' in quoted value",
                 'chips="a;hoy"; vienna=finger',
-                {"chips": "a;hoy", "vienna": "finger"},
+                {'chips': 'a;hoy', 'vienna': 'finger'},
             ),
             (
-                "Keep only the last set value",
-                "a=c; a=b",
-                {"a": "b"},
+                'Keep only the last set value',
+                'a=c; a=b',
+                {'a': 'b'},
             ),
         )
 
     def test_lenient_parsing(self):
         self._run_tests(
             (
-                "Ignore and try to skip invalid cookies",
+                'Ignore and try to skip invalid cookies',
                 'chips={"ahoy;": 1}; vienna="finger;"',
-                {"vienna": "finger;"},
+                {'vienna': 'finger;'},
             ),
             (
-                "Ignore cookies without a name",
-                "a=b; unnamed; c=d",
-                {"a": "b", "c": "d"},
+                'Ignore cookies without a name',
+                'a=b; unnamed; c=d',
+                {'a': 'b', 'c': 'd'},
             ),
             (
                 "Ignore '\"' cookie without name",
                 'a=b; "; c=d',
-                {"a": "b", "c": "d"},
+                {'a': 'b', 'c': 'd'},
             ),
             (
-                "Skip all space separated values",
-                "x a=b c=d x; e=f",
-                {"a": "b", "c": "d", "e": "f"},
+                'Skip all space separated values',
+                'x a=b c=d x; e=f',
+                {'a': 'b', 'c': 'd', 'e': 'f'},
             ),
             (
-                "Skip all space separated values",
+                'Skip all space separated values',
                 'x a=b; data={"complex": "json", "with": "key=value"}; x c=d x',
-                {"a": "b", "c": "d"},
+                {'a': 'b', 'c': 'd'},
             ),
             (
-                "Expect quote mending",
+                'Expect quote mending',
                 'a=b; invalid="; c=d',
-                {"a": "b", "c": "d"},
+                {'a': 'b', 'c': 'd'},
             ),
             (
-                "Reset morsel after invalid to not capture attributes",
-                "a=b; invalid; Version=1; c=d",
-                {"a": "b", "c": "d"},
+                'Reset morsel after invalid to not capture attributes',
+                'a=b; invalid; Version=1; c=d',
+                {'a': 'b', 'c': 'd'},
             ),
             (
-                "Reset morsel after invalid to not capture attributes",
-                "a=b; $invalid; $Version=1; c=d",
-                {"a": "b", "c": "d"},
+                'Reset morsel after invalid to not capture attributes',
+                'a=b; $invalid; $Version=1; c=d',
+                {'a': 'b', 'c': 'd'},
             ),
             (
-                "Continue after non-flag attribute without value",
-                "a=b; path; Version=1; c=d",
-                {"a": "b", "c": "d"},
+                'Continue after non-flag attribute without value',
+                'a=b; path; Version=1; c=d',
+                {'a': 'b', 'c': 'd'},
             ),
             (
-                "Allow cookie attributes with `$` prefix",
+                'Allow cookie attributes with `$` prefix',
                 'Customer="WILE_E_COYOTE"; $Version=1; $Secure; $Path=/acme',
-                {"Customer": ("WILE_E_COYOTE", {"version": "1", "secure": True, "path": "/acme"})},
+                {'Customer': ('WILE_E_COYOTE', {'version': '1', 'secure': True, 'path': '/acme'})},
             ),
             (
-                "Invalid Morsel keys should not result in an error",
-                "Key=Value; [Invalid]=Value; Another=Value",
-                {"Key": "Value", "Another": "Value"},
+                'Invalid Morsel keys should not result in an error',
+                'Key=Value; [Invalid]=Value; Another=Value',
+                {'Key': 'Value', 'Another': 'Value'},
             ),
         )
